<?php
/**
 * Formulaire de configuration
 *
 * @author		Jonathan OCHEJ
 * @license		MIT - https://github.com/GouvernementFR/dsfr/blob/main/LICENSE.md
 * 
 **/
if ( !defined('_ECRIRE_INC_VERSION') ) {
	return;
}

/**
 * Chargement du formulaire de configuration
 * 
 * @return array
 **/
function formulaires_configurer_dsfr_composants_charger_dist($id) {

	// fond du formulaire
	$fond = 'formulaires/configurer_dsfr_composants/'.$id;

	// validation du formulaire de configuration
	if ( !test_espace_prive() || !autoriser('configurer', '_dsfr_composants') || empty($id) || !trouver_fond($fond) ) {
		return false;
	}

	// charge les variables d'environnements du formulaire
	$valeurs = [
		'id'									=> $id, // compatibilité SPIP qui utilise cette variable
		'configurer'							=> 'dsfr_composants',
		'formulaire_configurer_dsfr_composants'	=> [
			'nom'			=> $id,
			'id'			=> 'formulaire_configurer_dsfr_composants_'.$id,
			'fond'			=> $fond,
			'icone'			=> find_in_path($fond.'.svg'),
		],
		'configurer_dsfr_composants'			=> dsfr_composants_configuration(), // tableau des clés à configurer
	];

	return $valeurs;
}

/**
 * Vérification du formulaire de configuration
 * 
 * @return array
 **/
function formulaires_configurer_dsfr_composants_verifier_dist($id) {
	$erreurs = [];

	// une configuration a été postée
	if ( !is_null($configuration_a_verifier = _request('configurer_dsfr_composants')) ) {
		// charge la configuration par défaut pour valider le formulaire
		$configuration_par_defaut = dsfr_composants_configuration_par_defaut();

		$erreurs_cle = [];

		// vérification uniquement des valeurs de la configuration envoyée par le formulaire
		foreach ( $configuration_a_verifier as $cle => $valeur ) {
			// la clé de configuration doit faire partie de la configuration par défaut
			if ( array_key_exists($cle, $configuration_par_defaut) ) {
				if ( $cle == 'api_js_option_mode' && !in_array($valeur, ['auto','manual','runtime','loaded']) ) {
					$erreurs['api_js_option_mode'] = 'Le mode est invalide !';
				}
			}
			else {
				$erreurs_cle[$cle] = $valeur;
			}
		}

		// il y a des erreurs de configuration ayant une clé invalide
		if ( !empty($erreurs_cle) ) {
			$erreurs['message_erreur'] = 'Configuration invalide : '.implode(',',array_keys($erreurs_cle));
			foreach ( $erreurs_cle as $cle => $valeur ) {
				$erreurs[$cle] = 'La clé de configuration '.$cle.' est invalide !';
			}
		}
	}
	else {
		$erreurs['message_erreur'] = 'Configuration invalide !';
	}

	return $erreurs;
}

/**
 * Traitement du formulaire de configuration
 * 
 * @return array
 **/
function formulaires_configurer_dsfr_composants_traiter_dist($id) {
	$traiter = false;

	$retours = [];

	// une configuration a été postée
	if ( !is_null($configuration_a_traiter = _request('configurer_dsfr_composants')) ) {
		// charge la configuration par défaut pour valider le formulaire
		$configuration_par_defaut = dsfr_composants_configuration_par_defaut();

		// gardons une trâce au cas où !
		$qui = [];
		if ( !empty($GLOBALS['visiteur_session']['id_auteur']) ) {
			$qui[] = 'id_auteur:'.$GLOBALS['visiteur_session']['id_auteur'];
		}
		if ( !empty($GLOBALS['visiteur_session']['nom']) ) {
			$qui[] = 'nom:'.$GLOBALS['visiteur_session']['nom'];
		}
		$qui[] = 'ip:'.$GLOBALS['ip'];
		$qui = '('.implode(', ',$qui).')';

		// valeurs des configurations de retour
		$retours['configurer_dsfr_composants'] = [];

		// traite uniquement les valeurs de la configuration envoyée par le formulaire
		foreach ( $configuration_a_traiter as $cle => $valeur ) {
			if ( is_string($configuration_par_defaut[$cle]) ) {
				// supprime les espaces en début et fin
				$valeur = trim($valeur);

				// correction automatique des valeurs booléennes par la configuration par défaut si la valeur est invalide
				if ( in_array($configuration_par_defaut[$cle], ['oui','non']) && !in_array($valeur, ['oui','non']) ) {
					$valeur = $configuration_par_defaut[$cle];
				}
			}

			// met à jour la valeur de retour
			if ( !is_null($valeur) ) {
				$retours['configurer_dsfr_composants'][$cle] = $valeur;
			}

			// forcer traiter positif si `NULL` car si cette valeur n'existe pas en BDD, `ecrire_config()` renverra `false`
			if ( ecrire_config('dsfr_composants/'.$cle, $valeur) || is_null($valeur) ) {
				$traiter = true;

				spip_log(
					"configurer $cle=".json_encode($valeur)." $qui",
					'dsfr_composants' . _LOG_INFO_IMPORTANTE
				);
			}
		}

		// met à jour les valeurs de configurations envoyées (dans le cas ou il y a eu des traitements)
		set_request('configurer_dsfr_composants', $retours['configurer_dsfr_composants']);

		// il y a eu des modification de la configuration
		if ( $traiter === true ) {
			dsfr_composants_purger();

			$retours['message_ok'] = _T('config_info_enregistree');
		}
	}

	// le formulaire reste éditable
	$retours['editable'] = true;

	return $retours;
}